@@ -1,9 +1,9 @@
 package Mouse;
-use 5.006_002;
+use 5.008_005;
 
 use Mouse::Exporter; # enables strict and warnings
 
-our $VERSION = '2.2.0';
+our $VERSION = '2.3.0';
 
 use Carp         ();
 use Scalar::Util ();
@@ -155,7 +155,7 @@ Mouse - Moose minus the antlers
 
 =head1 VERSION
 
-This document describes Mouse version 2.2.0
+This document describes Mouse version 2.3.0
 
 =head1 SYNOPSIS
 
@@ -402,10 +402,6 @@ We have a public git repository L<https://github.com/gfx/p5-Mouse>:.
 
     git clone git://github.com/gfx/p5-Mouse.git
 
-=head1 DEPENDENCIES
-
-Perl 5.6.2 or later.
-
 =head1 SEE ALSO
 
 L<Mouse::Role>
